# JADE
JADE provides a simple, flexible interface to submit jobs to an HPC.

[![PyPI](https://img.shields.io/pypi/pyversions/NREL-jade.svg)](https://pypi.python.org/pypi/nrel-jade)
[![Documentation](https://img.shields.io/badge/docs-ready-blue.svg)](https://nrel.github.io/jade/)

## Documentation
Documentation: https://nrel.github.io/jade/

Tutorial: https://nrel.github.io/jade/tutorial.html

## Installation

```bash
pip install NREL-jade
```
